# Generated by Django 5.2.11 on 2026-02-23 04:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nsot', '0044_attribute_depends_on'),
    ]

    operations = [
        migrations.AddField(
            model_name='attribute',
            name='inheritable',
            field=models.BooleanField(default=False, help_text="Whether this Attribute's values are inherited by child resources that do not define their own explicit value. Only allowed for resource types with parent-child hierarchies (Network, Interface)."),
        ),
    ]
